==> uremote_1.0.0.orig.tar.gz: uremote-1.0.0.orig/src/main.cpp <==
//  © Copyright 2010 Reuben D'Netto (rdnetto+uremote@gmail.com)
//  This file is part of uRemote v1.0
//
//  uRemote is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  uRemote is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with uRemote.  If not, see <http://www.gnu.org/licenses/>.


#include <QtGui/QApplication>
#include "mainwindow.h"
#include <qapplication.h>
#include <stdio.h>
#include <stdlib.h>
#include <QFile>
#include <QDateTime>

QFile Log("/var/log/uRemote.log");

void ErrorHandler(QtMsgType, const char *msg){
	printf(msg);
	printf("\n");
	Log.write(msg);
	Log.write("\n");
}

int main(int argc, char *argv[]){
	qDebug(("Running Qt " + QString(qVersion())).toLocal8Bit());

	//delete when size exceeds 100 KB
	if(Log.size() > (1 << 10) * 100) Log.remove();

	Log.open(QIODevice::Append | QIODevice::WriteOnly | QIODevice::Text);
	Log.write(("\n\n" + QDate::currentDate().toString() + "\n").toLocal8Bit());
	qInstallMsgHandler(ErrorHandler);


	QApplication a(argc, argv);
	MainWindow w;
	w.show();
	int ret = a.exec();
	Log.flush();
	Log.close();
	return ret;
}

==> uremote_1.0.1.tar.gz: uremote-1.0.1/src/main.cpp <==
//  © Copyright 2010 Reuben D'Netto (rdnetto+uremote@gmail.com)
//  This file is part of uRemote v1.0
//
//  uRemote is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  uRemote is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with uRemote.  If not, see <http://www.gnu.org/licenses/>.


#include <QtGui/QApplication>
#include "mainwindow.h"
#include <qapplication.h>
#include <stdio.h>
#include <stdlib.h>
#include <QFile>
#include <QDateTime>

QFile Log("/var/log/uRemote.log");

QByteArray CensorHashes(QString msg){
	static QRegExp hashExp("[0-9A-F]{40,40}"); //matches a 40 char hex string
	static QChar spacer = 'X';

	for(int start = 0, i = msg.indexOf(hashExp, start); i != -1; start = i + 1, i = msg.indexOf(hashExp, start)){
		//censor the 20 digits in the center
		for(int j = 10; j < 30; j += 1)
			msg[i + j] = spacer;
	} //end for

	return msg.toLocal8Bit();
}

void ErrorHandler(QtMsgType, const char *msg){
	printf(msg);
	printf("\n");
	Log.write(CensorHashes(msg));
	Log.write("\n");
}

int main(int argc, char *argv[]){
	qDebug(("Running Qt " + QString(qVersion())).toLocal8Bit());

	//delete when size exceeds 10 KB
	if(Log.size() > (1 << 10) * 10) Log.remove();

	Log.open(QIODevice::Append | QIODevice::WriteOnly | QIODevice::Text);
	Log.write(("\n\n" + QDate::currentDate().toString() + "\n").toLocal8Bit());
	qInstallMsgHandler(ErrorHandler);


	QApplication a(argc, argv);
	MainWindow w;
	w.show();
	int ret = a.exec();
	Log.flush();
	Log.close();
	return ret;
}
